==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/TabHeaderElement.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { DragService } from "./DragService";
/**
 * @hidden
 */
var TabHeaderElement = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TabHeaderElement, _super);
    function TabHeaderElement() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(TabHeaderElement.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TabHeaderElement.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.n = this.d;
        },
        enumerable: false,
        configurable: true
    });
    TabHeaderElement.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(TabHeaderElement.prototype, "a", {
        get: function () {
            var ret_ = this.c.l("dragService", function (a) { return new DragService(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("dragService", value_);
        },
        enumerable: false,
        configurable: true
    });
    TabHeaderElement.$t = markType(TabHeaderElement, 'TabHeaderElement', BaseElement.$);
    return TabHeaderElement;
}(BaseElement));
export { TabHeaderElement };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/TabHeaderElement.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { DragService } from "./DragService";
/**
 * @hidden
 */
var TabHeaderElement = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TabHeaderElement, _super);
    function TabHeaderElement() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(TabHeaderElement.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TabHeaderElement.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.o = this.d;
        },
        enumerable: false,
        configurable: true
    });
    TabHeaderElement.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(TabHeaderElement.prototype, "a", {
        get: function () {
            var ret_ = this.c.m("dragService", function (a) { return new DragService(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("dragService", value_);
        },
        enumerable: false,
        configurable: true
    });
    TabHeaderElement.$t = markType(TabHeaderElement, 'TabHeaderElement', BaseElement.$);
    return TabHeaderElement;
}(BaseElement));
export { TabHeaderElement };
